pub struct SenderOptionsBuilder { /* private fields */ }Expand description
Builder for configuring SendOptions with ergonomic method chaining
Implementations
Sourceimpl SenderOptionsBuilder
impl SenderOptionsBuilder
Sourcepub fn clock_video(self, clock: bool) -> Self
pub fn clock_video(self, clock: bool) -> Self
Configure whether to clock video
Sourcepub fn clock_audio(self, clock: bool) -> Self
pub fn clock_audio(self, clock: bool) -> Self
Configure whether to clock audio
Sourcepub fn build(self) -> SenderOptions
pub fn build(self) -> SenderOptions
Build the sender options
This method is infallible and simply applies defaults for any unset options.
Validation is performed when creating a Sender via Sender::new().
Example
let options = SenderOptions::builder("My Sender").build();
let sender = Sender::new(&ndi, &options)?;Trait Implementations
Sourceimpl Clone for SenderOptionsBuilder
impl Clone for SenderOptionsBuilder
Sourcefn clone(&self) -> SenderOptionsBuilder
fn clone(&self) -> SenderOptionsBuilder
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for SenderOptionsBuilder
impl RefUnwindSafe for SenderOptionsBuilder
impl Send for SenderOptionsBuilder
impl Sync for SenderOptionsBuilder
impl Unpin for SenderOptionsBuilder
impl UnsafeUnpin for SenderOptionsBuilder
impl UnwindSafe for SenderOptionsBuilder